"""
fields automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class Fields(BaseModel):
    media_fields: Optional[str] = Field(default=None, alias="media.fields")
    place_fields: Optional[str] = Field(default=None, alias="place.fields")
    poll_fields: Optional[str] = Field(default=None, alias="poll.fields")
    tweet_fields: Optional[str] = Field(default=None, alias="tweet.fields")
    user_fields: Optional[str] = Field(default=None, alias="user.fields")
    pass
