"""
pagination automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class Pagination(BaseModel):
    start_time: Optional[str] = Field(default=None, alias="start_time")
    end_time: Optional[str] = Field(default=None, alias="end_time")
    since_id: Optional[str] = Field(default=None, alias="since_id")
    until_id: Optional[str] = Field(default=None, alias="until_id")
    max_results: Optional[int] = Field(default=None, alias="max_results")
    pagination_token: Optional[str] = Field(default=None, alias="pagination_token")
    pass
