"""
tweet_details automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
class TweetDetails(BaseModel):
    id: Optional[str] = Field(default=None, alias="id")
    text: Optional[str] = Field(default=None, alias="text")
    created_at: Optional[datetime.datetime] = Field(default=None, alias="created_at")
    author_id: Optional[str] = Field(default=None, alias="author_id")
    edit_history_tweet_ids: Optional[List[str]] = Field(default=None, alias="edit_history_tweet_ids")
    conversation_id: Optional[str] = Field(default=None, alias="conversation_id")
    in_reply_to_user_id: Optional[str] = Field(default=None, alias="in_reply_to_user_id")
    pass
